Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(700)

Unified Diff: sdk/lib/utf/utf_core.dart

Issue 12282038: Remove deprecated string features. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sdk/lib/utf/utf_core.dart
diff --git a/sdk/lib/utf/utf_core.dart b/sdk/lib/utf/utf_core.dart
index 15ca45e356eb0c292917f7ca42c6d4f0b1c33966..d733b53198e5af29733c4d3c9cd6e0bdc557473f 100644
--- a/sdk/lib/utf/utf_core.dart
+++ b/sdk/lib/utf/utf_core.dart
@@ -9,9 +9,9 @@ part of dart.utf;
* Provide a list of Unicode codepoints for a given string.
*/
List<int> stringToCodepoints(String str) {
// Note: str.charCodes gives us 16-bit code units on all Dart implementations.
// So we need to convert.
- return _utf16CodeUnitsToCodepoints(str.charCodes);
+ return _utf16CodeUnitsToCodepoints(str.codeUnits);
}
/**
@@ -9,9 +9,9 @@ part of dart.utf;
*/
List<int> stringToCodepoints(String str) {
- // Note: str.charCodes gives us 16-bit code units on all Dart implementations.
+ // Note: str.codeUnits gives us 16-bit code units on all Dart implementations.
// So we need to convert.

Powered by Google App Engine
This is Rietveld 408576698